@@ -14,7 +14,15 @@ use Class::Tiny qw(
   surname
 );
 
-our $names;
+#
+# Package variables
+#
+
+our $names;    # loaded names data
+
+#
+# Class methods
+#
 
 sub load {
     my $yaml_path = shift // dist_file( 'Data-Gimei', 'names.yml' );
@@ -38,6 +46,10 @@ sub BUILDARGS {
     return \%args;
 }
 
+#
+# Instance methods
+#
+
 sub to_s {
     my $self = shift;
 
